@@ -15,6 +15,7 @@ use constant    linux       => enterprises . '.8072.3.2.10' ;
 use constant    ucddavis    => enterprises . '.2021' ;
 use constant    checkpoint  => enterprises . '.2620' ;
 use constant    synology    => enterprises . '.6574' ;
+use constant    ubnt        => enterprises . '.41112' ;
 
 use constant    ucdExperimental => ucddavis . '.13' ;
 
@@ -45,6 +46,11 @@ use constant    snmpEngineID    => snmpEngine . '.1.0';
 use constant    hrStorageEntry  => iso . '.25.2.3.1.3';
 use constant    hrSWRunName     => iso . '.25.4.2.1.2';
 
+# UBNT-UniFi-MIB
+use constant    ubntUniFi               => ubnt . '.1.6' ;
+use constant    unifiApSystemModel      => ubntUniFi . '.3.3.0' ;
+use constant    unifiApSystemVersion    => ubntUniFi . '.3.6.0' ;
+
 our $mibSupport = [
     {
         name        => "linux",
@@ -106,6 +112,16 @@ sub getType {
         };
         return 'NETWORKING';
     }
+
+    # UniFi AP detection
+    my $unifiModel = $self->get(unifiApSystemModel);
+    if ($unifiModel) {
+        $device->{_Appliance} = {
+            MODEL           => $unifiModel,
+            MANUFACTURER    => 'Ubiquiti'
+        };
+        return 'NETWORKING';
+    }
 }
 
 sub _hasProcess {
@@ -144,6 +160,9 @@ sub getManufacturer {
 sub getSerial {
     my ($self) = @_;
 
+    my $device = $self->device
+        or return;
+
     my $manufacturer = $self->getManufacturer()
         or return;
 
@@ -160,6 +179,9 @@ sub getSerial {
             $snmpEngineID =~ s/^0x//;
             $serial = $snmpEngineID;
         }
+    } elsif ($manufacturer eq 'Ubiquiti' && $device->{MAC}) {
+        $serial = $device->{MAC};
+        $serial =~ s/://g;
     }
 
     return $serial;
@@ -191,6 +213,14 @@ sub run {
             VERSION         => getCanonicalString($self->get(svnVersion)),
             MANUFACTURER    => $manufacturer
         };
+    } elsif ($manufacturer eq 'Ubiquiti') {
+        $firmware = {
+            NAME            => $self->getModel(),
+            DESCRIPTION     => "Unifi AP System version",
+            TYPE            => "system",
+            VERSION         => getCanonicalString($self->get(unifiApSystemVersion)),
+            MANUFACTURER    => $manufacturer
+        };
     }
     $device->addFirmware($firmware) if $firmware;
 }
