@@ -3,6 +3,8 @@ package FusionInventory::Agent::Task::Inventory::Virtualization::Libvirt;
 use strict;
 use warnings;
 
+use parent 'FusionInventory::Agent::Task::Inventory::Module';
+
 use English qw(-no_match_vars);
 use XML::TreePP;
 
@@ -39,13 +41,13 @@ sub _getMachines {
     my $uri_param = $params{'uri'} ? "-c ".$params{'uri'} : "";
 
     my @machines = _parseList(
-        command => "virsh $uri_param list --all",
+        command => "virsh $uri_param --readonly list --all",
         logger  => $params{logger}
     );
 
     foreach my $machine (@machines) {
         my %infos = _parseDumpxml(
-            command => "virsh $uri_param dumpxml $machine->{NAME}",
+            command => "virsh $uri_param --readonly dumpxml $machine->{NAME}",
             logger  => $params{logger}
         );
 
@@ -70,7 +72,6 @@ sub _parseList {
         next if $line =~ /^-{5}/;
         next unless $line =~ /^\s*(\d+|)(\-|)\s+(\S+)\s+(\S.+)/;
 
-        my $vmid = $1;
         my $name = $3;
 
         # ignore Xen Dom0
@@ -83,7 +84,6 @@ sub _parseList {
             NAME      => $name,
             STATUS    => $status,
             VMTYPE    => "libvirt",
-            VMID      => $vmid,
         };
 
         push @machines, $machine;
