@@ -256,6 +256,9 @@ sub getDevicesFromProc {
     my %seen;
     @names = grep { !$seen{$_}++ } @names;
 
+    # filter multipath
+    @names = _filterMultipath(names => \@names) if canRun('multipath');
+
     my $udisksctl = canRun('udisksctl');
     $dump->{udisksctl} = 1 if ($dump && $udisksctl);
     $udisksctl = 1 if $root && -e "$root/udisksctl";
@@ -276,6 +279,10 @@ sub getDevicesFromProc {
                     'removable' : 'disk'
         };
 
+        # WWN
+        my $wwn = _getValueFromSysProc($logger, $name, 'wwid', $root, $dump);
+        $device->{WWN} = $wwn if $wwn && $wwn =~ s/^naa\./wwn-/;
+
         # Support PCI or other bus case as description
         foreach my $subsystem ("device/subsystem","device/device/subsystem") {
             my $link = _readLinkFromSysFs("/sys/block/$name/$subsystem", $root, $dump);
@@ -339,11 +346,42 @@ sub _getValueFromSysProc {
     my $value = getFirstLine(file => $root.$file, logger => $logger);
 
     return undef unless defined $value;
-    $value =~ s/^\W*([\w\s]+)\W*$/$1/;
+    $value = $1 if $value =~ /([[:print:]]*[[:alnum:]]+)/;
 
     return trimWhitespace($value);
 }
 
+sub _filterMultipath {
+    my (%params) = (
+        command => 'multipath -l',
+        @_
+    );
+
+    my %hnames = map {$_ => 1} @{$params{names}};
+
+    # parse multipath
+    my (@groups, @group);
+    foreach my $line (getAllLines(%params)) {
+        if ($line =~ /^\w+ \(\w+\) dm-\d+ \w+/) {
+            push @groups, [@group] if scalar @group;
+            @group = ();
+        } elsif ($line =~ / (sd[a-z]+) /) {
+            push @group, $1;
+        }
+    }
+    push @groups, [@group] if scalar @group;
+
+    # filter
+    foreach my $group (@groups) {
+        # delete all but first element from each group
+        for (my $i = 1; $i < scalar @$group; $i++) {
+            delete $hnames{ @$group[$i] } ;
+        }
+    }
+
+    return keys %hnames;
+}
+
 sub _readLinkFromSysFs {
     my ($path, $root, $dump) = @_;
 
@@ -385,54 +423,88 @@ sub _readLinkFromSysFs {
 sub getInfoFromSmartctl {
     my (%params) = @_;
 
-    my $handle = getFileHandle(
+    # We need to support dump params to permit full testing when root params is set
+    $params{file} = "$params{root}/smartctl-".basename($params{device})
+        if $params{root};
+
+    my @lines = getAllLines(
         %params,
-        command => $params{device} ? "smartctl -i $params{device}" : undef,
+        command => $params{device} ?
+            "smartctl -i $params{device} " . ($params{extra} // "") : undef,
     );
-    return unless $handle;
+
+    # We need to support dump params to permit full testing when root params is set
+    $params{dump}->{"smartctl-".basename($params{device})} = @lines ? join("\n", @lines)."\n" : ""
+        if $params{dump};
+
+    return unless @lines;
 
     my $info = {
         TYPE        => 'disk',
         DESCRIPTION => 'SATA',
     };
 
-    while (my $line = <$handle>) {
-        if ($line =~ /^Vendor: +(\S+)/i) {
-            $info->{MANUFACTURER} = getCanonicalManufacturer($1);
-            next;
+    my $attrs = {
+        DESCRIPTION => {
+            src => ['transport protocol']
+        },
+        DISKSIZE => {
+            src  => ['user capacity'],
+            func => \&getCanonicalSize,
+        },
+        FIRMWARE => {
+            src => ['revision', 'firmware version']
+        },
+        INTERFACE => {
+            src => ['transport protocol', 'sata version is']
+        },
+        MANUFACTURER => {
+            src  => ['vendor', 'model family', 'add. product id', 'device model', 'product'],
+            func => \&getCanonicalManufacturer,
+        },
+        MODEL => {
+            src => ['product', 'device model', 'model family']
+        },
+        SERIALNUMBER => {
+            src => ['serial number']
+        },
+        TYPE => {
+            src => ['device type']
+        },
+        WWN => {
+            src  => ['lu wwn device id'],
+            # remove whitespaces
+            func => sub { shift =~ s/\s+//gr },
         }
+    };
 
-        if ($line =~ /^Product: +(\S+)/i) {
-            $info->{MODEL} = $1;
-            next;
-        }
+    my $regexp = {
+        __default          => qr/^(\w+)/,
+        __smartctl         => qr/^([^:]+?)\s*:\s*(.+)\s*$/,
+        'user capacity'    => qr/([\d\.\,\s]+(?:\w+)?)/,
+        'device model'     => qr/([\w\s\-]+)/,
+        'firmware version' => qr/(\S+)/,
+        'lu wwn device id' => qr/((?:0x)?[[:xdigit:]\h]+)/,
+    };
 
-        if ($line =~ /^Revision: +(\S+)/i) {
-            $info->{FIRMWARE} = $1;
-            next;
-        }
+    my %smartctl;
 
-        if ($line =~ /^User Capacity: +(\S.+\S)/i) {
-            $info->{DISKSIZE} = getCanonicalSize($1, 1024);
-            next;
-        }
+    for my $line (@lines) {
+        next unless $line =~ $regexp->{__smartctl};
+        $smartctl{lc $1} = $2;
+    }
 
-        if ($line =~ /^Transport protocol: +(\S+)/i) {
-            $info->{DESCRIPTION} = $1;
-            next;
-        }
+    while (my ($attr, $val) = each %$attrs) {
+        for my $s (@{$val->{src}}) {
+            next unless defined $smartctl{$s};
 
-        if ($line =~ /^Device type: +(\S+)/i) {
-            $info->{TYPE} = $1;
-            next;
-        }
+            my ($data) = ($smartctl{$s} =~ ($regexp->{$s} // $regexp->{__default}));
 
-        if ($line =~ /^Serial number: +(\S+)/i) {
-            $info->{SERIALNUMBER} = $1;
-            next;
+            $info->{$attr} = exists $val->{func} ? &{$val->{func}}($data) : $data;
+
+            last;
         }
     }
-    close $handle;
 
     return $info;
 }
